==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatformOperatingSystem;
import com.okta.sdk.resource.model.PolicyPlatformType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatform
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatform.JSON_PROPERTY_OS,
        PlatformConditionEvaluatorPlatform.JSON_PROPERTY_TYPE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class PlatformConditionEvaluatorPlatform implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OS = "os";
    private PlatformConditionEvaluatorPlatformOperatingSystem os;

    public static final String JSON_PROPERTY_TYPE = "type";
    private PolicyPlatformType type;

    public PlatformConditionEvaluatorPlatform() {
    }

    public PlatformConditionEvaluatorPlatform os(PlatformConditionEvaluatorPlatformOperatingSystem os) {

        this.os = os;
        return this;
    }

    /**
     * Get os
     *
     * @return os
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionEvaluatorPlatformOperatingSystem getOs() {
        return os;
    }

    @JsonProperty(JSON_PROPERTY_OS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOs(PlatformConditionEvaluatorPlatformOperatingSystem os) {
        this.os = os;
    }

    public PlatformConditionEvaluatorPlatform type(PolicyPlatformType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPlatformType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(PolicyPlatformType type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatform platformConditionEvaluatorPlatform = (PlatformConditionEvaluatorPlatform) o;
        return Objects.equals(this.os, platformConditionEvaluatorPlatform.os)
                && Objects.equals(this.type, platformConditionEvaluatorPlatform.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(os, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatform {\n");
        sb.append("    os: ").append(toIndentedString(os)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/PlatformConditionEvaluatorPlatform.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.PlatformConditionEvaluatorPlatformOperatingSystem;
import com.okta.sdk.resource.model.PolicyPlatformType;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * PlatformConditionEvaluatorPlatform
 */
@JsonPropertyOrder({ PlatformConditionEvaluatorPlatform.JSON_PROPERTY_OS,
        PlatformConditionEvaluatorPlatform.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class PlatformConditionEvaluatorPlatform implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_OS = "os";
    private PlatformConditionEvaluatorPlatformOperatingSystem os;

    public static final String JSON_PROPERTY_TYPE = "type";
    private PolicyPlatformType type;

    public PlatformConditionEvaluatorPlatform() {
    }

    public PlatformConditionEvaluatorPlatform os(PlatformConditionEvaluatorPlatformOperatingSystem os) {

        this.os = os;
        return this;
    }

    /**
     * Get os
     *
     * @return os
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_OS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PlatformConditionEvaluatorPlatformOperatingSystem getOs() {
        return os;
    }

    @JsonProperty(JSON_PROPERTY_OS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOs(PlatformConditionEvaluatorPlatformOperatingSystem os) {
        this.os = os;
    }

    public PlatformConditionEvaluatorPlatform type(PolicyPlatformType type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public PolicyPlatformType getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(PolicyPlatformType type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        PlatformConditionEvaluatorPlatform platformConditionEvaluatorPlatform = (PlatformConditionEvaluatorPlatform) o;
        return Objects.equals(this.os, platformConditionEvaluatorPlatform.os)
                && Objects.equals(this.type, platformConditionEvaluatorPlatform.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(os, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class PlatformConditionEvaluatorPlatform {\n");
        sb.append("    os: ").append(toIndentedString(os)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
